apply_fade_in_out: Apply fade-out and in

Description Usage Arguments See Also

View source: R/fade.R

Description

Function used to apply a fade out and in effect to a wave

Usage

1
apply_fade_in_out(wave, fade_in, fade_out = rev(fade_in))

Arguments

wave

A numeric vector longer than fade as made by make_wave for example

fade_in

A numeric vector shorter than wave as made by make_fade for example

fade_out

A numeric vector shorter than wave as made by make_fade for example

See Also

apply_fade_in apply_fade_out


galyfray/RSyntWave documentation built on Jan. 31, 2021, 2:02 a.m.