Description Usage Arguments See Also
Function used to apply a fade out and in effect to a wave
1 | apply_fade_in_out(wave, fade_in, fade_out = rev(fade_in))
|
wave |
A numeric vector longer than fade as made by |
fade_in |
A numeric vector shorter than wave as made by |
fade_out |
A numeric vector shorter than wave as made by |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.